@@ -5,6 +5,7 @@ use strict;
 use warnings;
 use FindBin;
 use Test::More;
+use JSON::PP;
 
 BEGIN {
   eval { require WorePAN };
@@ -20,6 +21,7 @@ sub run {
 
   my ($name) = $file =~ /(\w+)\.t$/;
 
+  local $Module::CPANTS::Kwalitee::Files::RespectManiskip = 0;
   for my $test (@tests) {
     my $worepan = WorePAN->new(
       root => "$FindBin::Bin/../../tmp",
